import { CloudAssembly, MissingContext } from './cloud-assembly';
import { Environment } from './environment';
import { MetadataEntry, SynthesisMessage } from './metadata';
export declare enum ArtifactType {
    None = "none",
    AwsCloudFormationStack = "aws:cloudformation:stack"
}
export interface Artifact {
    readonly type: ArtifactType;
    readonly environment: string;
    readonly metadata?: {
        [path: string]: MetadataEntry[];
    };
    readonly dependencies?: string[];
    readonly missing?: {
        [key: string]: MissingContext;
    };
    readonly properties?: {
        [name: string]: any;
    };
    readonly autoDeploy?: boolean;
}
export interface AwsCloudFormationStackProperties {
    readonly templateFile: string;
    readonly parameters?: {
        [id: string]: string;
    };
}
export declare class CloudArtifact {
    readonly assembly: CloudAssembly;
    readonly id: string;
    static from(assembly: CloudAssembly, name: string, artifact: Artifact): CloudArtifact;
    readonly type: ArtifactType;
    readonly missing: {
        [key: string]: MissingContext;
    };
    readonly autoDeploy: boolean;
    readonly messages: SynthesisMessage[];
    readonly environment: Environment;
    readonly metadata: {
        [path: string]: MetadataEntry[];
    };
    readonly dependsIDs: string[];
    readonly properties: {
        [name: string]: any;
    };
    private _deps?;
    constructor(assembly: CloudAssembly, id: string, artifact: Artifact);
    readonly depends: CloudArtifact[];
    private renderMessages;
}
