import { Artifact, CloudArtifact } from './cloud-artifact';
import { CloudFormationStackArtifact } from './cloudformation-artifact';
export interface AssemblyManifest {
    /**
     * Protocol version
     */
    readonly version: string;
    /**
     * The set of artifacts in this assembly.
     */
    readonly artifacts?: {
        [id: string]: Artifact;
    };
    /**
     * Runtime information.
     */
    readonly runtime?: RuntimeInfo;
}
export declare class CloudAssembly {
    readonly directory: string;
    readonly artifacts: CloudArtifact[];
    readonly version: string;
    readonly missing?: {
        [key: string]: MissingContext;
    };
    readonly runtime: RuntimeInfo;
    readonly manifest: AssemblyManifest;
    constructor(directory: string);
    tryGetArtifact(id: string): CloudArtifact | undefined;
    getStack(id: string): CloudFormationStackArtifact;
    readJson(filePath: string): any;
    readonly stacks: CloudFormationStackArtifact[];
    private validateDeps;
    private renderArtifacts;
    private renderMissing;
}
export declare class CloudAssemblyBuilder {
    readonly outdir: string;
    private readonly artifacts;
    constructor(outdir?: string);
    addArtifact(name: string, artifact: Artifact): void;
    build(options?: BuildOptions): CloudAssembly;
}
export interface BuildOptions {
    /**
     * Include runtime information (module versions) in manifest.
     * @default true
     */
    readonly runtimeInfo?: RuntimeInfo;
}
/**
 * Information about the application's runtime components.
 */
export interface RuntimeInfo {
    /**
     * The list of libraries loaded in the application, associated with their versions.
     */
    readonly libraries: {
        [name: string]: string;
    };
}
/**
 * Represents a missing piece of context.
 */
export interface MissingContext {
    readonly provider: string;
    readonly props: {
        account?: string;
        region?: string;
        [key: string]: any;
    };
}
